/// <reference types="react" />
import { ILogger } from 'ts-smart-logger';
import { BaseTextField } from '../text-field/base-text-field.component';
import { AnyT, EntityIdT } from '../../../definitions.interface';
import { ChangeEventT, IBaseEvent, IBaseSelectProps, IBaseSelectState, IMenuProps, IMultiItemEntity, IPresetsSelectOptionEntity, SelectValueT } from '../../../definition';
export declare class BaseSelect<TProps extends IBaseSelectProps, TState extends IBaseSelectState> extends BaseTextField<TProps, TState> {
    protected static readonly logger: ILogger;
    private readonly menuRef;
    private readonly quickFilterQueryTask;
    /**
     * @stable [30.11.2019]
     * @param {TProps} props
     */
    constructor(props: TProps);
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onChange(event: ChangeEventT): void;
    /**
     * @stable [29.01.2020]
     * @param {Readonly<TProps extends IBaseSelectProps>} prevProps
     * @param {Readonly<TState extends IBaseSelectState>} prevState
     */
    componentDidUpdate(prevProps: Readonly<TProps>, prevState: Readonly<TState>): void;
    /**
     * @stable [31.01.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEscape(event: IBaseEvent): void;
    /**
     * @stable [30.01.2020]
     */
    clearValue(): void;
    /**
     * @stable [11.01.2020]
     */
    openMenu(): void;
    /**
     * @stable [16.01.2020]
     * @param {IBaseEvent} event
     */
    onKeyEnter(event: IBaseEvent): void;
    deleteItem(item: IMultiItemEntity): void;
    /**
     * @stable [28.01.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [16.06.2020]
     * @returns {JSX.Element}
     */
    protected readonly attachmentElement: JSX.Element;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected readonly inputAttachmentElement: JSX.Element;
    /**
     * @stable [09.01.2020]
     * @returns {IMenuProps}
     */
    protected getMenuProps(): IMenuProps;
    /**
     * @stable [31.01.2020]
     * @param {(option: ISelectOptionEntity) => boolean} filter
     * @returns {IPresetsSelectOptionEntity[]}
     */
    protected getFilteredOptions(filter?: (option: IPresetsSelectOptionEntity) => boolean): IPresetsSelectOptionEntity[];
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected readonly isBusy: boolean;
    /**
     * @stable [16.06.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [28.01.2020]
     * @param {IPresetsSelectOptionEntity} option
     */
    protected onSelect(option: IPresetsSelectOptionEntity): void;
    /**
     * @stable [16.06.2020]
     * @param {IPresetsSelectOptionEntity} option
     * @param {boolean} isInlineOptionSelected
     */
    protected onInlineOptionClick(option: IPresetsSelectOptionEntity, isInlineOptionSelected: boolean): void;
    /**
     * @stable [16.06.2020]
     * @param {EntityIdT} id
     * @param {SelectValueT} currentValue
     * @returns {boolean}
     */
    protected isInlineOptionSelected(id: EntityIdT, currentValue: SelectValueT): boolean;
    /**
     * @stable [11.01.2020]
     * @param {IPresetsSelectOptionEntity} option
     */
    protected notifySelectOption(option: IPresetsSelectOptionEntity): void;
    /**
     * @stable [28.01.2020]
     * @param {SelectValueT} value
     * @returns {AnyT}
     */
    protected getDecoratedDisplayValue(value: SelectValueT): AnyT;
    /**
     * @stable [28.01.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected decorateDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [16.06.2020]
     * @returns {IPresetsSelectOptionEntity[]}
     */
    protected readonly options: IPresetsSelectOptionEntity[];
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    protected readonly isExpandActionRendered: boolean;
    /**
     * @stable [28.01.2020]
     * @returns {boolean}
     */
    protected readonly isAllowEmptyFilterValue: boolean;
    /**
     * @stable [08.07.2020]
     * @param {SelectValueT} value
     * @returns {EntityIdT}
     */
    protected fromSelectValueToId(value: SelectValueT): EntityIdT;
    /**
     * @stable [16.06.2020]
     * @returns {TProps}
     */
    protected getSettingsProps(): TProps;
    /**
     * @stable [28.01.2020]
     */
    private notifyQuickSearchFilterChange;
    /**
     * @stable [11.01.2020]
     * @param {IBaseEvent} event
     */
    private onDropDownClick;
    /**
     * @stable [28.01.2020]
     * @param {IPresetsSelectOptionEntity} option
     */
    private doSelectOption;
    /**
     * @stable [16.06.2020]
     * @param {string} query
     */
    private onFilterChange;
    /**
     * @stable [11.01.2020]
     */
    private hideMenu;
    /**
     * @stable [12.01.2020]
     * @param {boolean} force
     */
    private renderAndShowMenu;
    /**
     * @stable [16.01.2020]
     */
    private startQuickSearchIfApplicable;
    /**
     * @stable [28.01.2020]
     */
    private onOptionsLoadDone;
    /**
     * @stable [30.01.2020]
     * @param {boolean} noDelay
     */
    private hideMenuAndStartQuickSearch;
    /**
     * @stable [29.01.2020]
     * @param {TProps} props
     * @param {TProps} previousProps
     */
    private tryResetCachedValue;
    /**
     * @stable [18.05.2020]
     */
    private cancelQueryFilterTask;
    /**
     * @stable [30.01.2020]
     * @param {() => void} callback
     */
    private clearCachedValue;
    /**
     * @stable [30.01.2020]
     * @param {IPresetsSelectOptionEntity} value
     * @param {() => void} callback
     */
    private saveCachedValue;
    /**
     * @stable [08.07.2020]
     * @param {SelectValueT} value
     * @returns {StringNumberT}
     */
    private fromSelectValueToDisplayValue;
    /**
     * @stable [16.06.2020]
     * @returns {number}
     */
    private getMenuWidth;
    /**
     * @stable [16.06.2020]
     * @returns {AnyT}
     */
    protected readonly originalEmptyValue: AnyT;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly isQuickSearchEnabled;
    /**
     * @stable [11.01.2020]
     * @returns {number}
     */
    private readonly delayTimeout;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly areLocalOptionsUsed;
    /**
     * @stable [24.01.2020]
     * @returns {boolean}
     */
    private readonly isMenuAnchored;
    /**
     * @stable [01.02.2020]
     * @returns {boolean}
     */
    private readonly isForceUseLocalFilter;
    /**
     * @stable [24.01.2020]
     * @returns {HTMLElement}
     */
    private getMenuAnchorElement;
    /**
     * @stable [30.01.2020]
     * @returns {IPresetsSelectOptionEntity}
     */
    private readonly $$cashedValue;
    /**
     * @stable [01.02.2020]
     * @returns {string}
     */
    private readonly dictionary;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly doOptionsExist;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly isMenuAlreadyRenderedAndOpened;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly isForceReload;
    /**
     * @stable [16.06.2020]
     * @returns {boolean}
     */
    private readonly isMenuRendered;
    /**
     * @stable [16.06.2020]
     * @returns {IMenu}
     */
    private readonly menu;
}
