"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var definitions_interface_1 = require("../../definitions.interface");
var util_1 = require("../../util");
var generic_component_1 = require("../base/generic.component");
var basic_list_component_1 = require("../list/basic/basic-list.component");
var dialog_component_1 = require("../dialog/dialog.component");
var list_item_component_1 = require("../list/item/list-item.component");
var definition_1 = require("../../definition");
var text_field_1 = require("../field/text-field");
var perfect_scroll_plugin_1 = require("../plugin/perfect-scroll.plugin");
var inline_option_component_1 = require("../inline-option/inline-option.component");
var basic_component_1 = require("../base/basic.component");
var button_component_1 = require("../button/button.component");
var Menu = /** @class */ (function (_super) {
    __extends(Menu, _super);
    /**
     * @stable [24.01.2020]
     * @param {IMenuProps} props
     */
    function Menu(props) {
        var _this = _super.call(this, props) || this;
        _this.dialogRef = React.createRef();
        _this.fieldRef = React.createRef();
        _this.listElementRef = React.createRef();
        /**
         * @stable [17.06.2019]
         * @param {IPresetsMenuItemEntity} itm
         * @returns {StringNumberT}
         */
        _this.optionValueFn = function (itm) { return (itm.label ? _this.t(itm.label) : itm.value); };
        _this.hide = _this.hide.bind(_this);
        _this.onDialogActivate = _this.onDialogActivate.bind(_this);
        _this.onDialogAfterDestroy = _this.onDialogAfterDestroy.bind(_this);
        _this.onDialogAfterRender = _this.onDialogAfterRender.bind(_this);
        _this.onDialogDeactivate = _this.onDialogDeactivate.bind(_this);
        _this.onFilterValueChange = _this.onFilterValueChange.bind(_this);
        _this.onSelect = _this.onSelect.bind(_this);
        _this.scrollEventCallbackCondition = _this.scrollEventCallbackCondition.bind(_this);
        _this.state = { opened: false };
        if (_this.isFilterUsed) {
            _this.filterQueryTask = new util_1.DelayedTask(_this.notifyFilterChange.bind(_this), props.delayTimeout);
        }
        return _this;
    }
    /**
     * @stable [24.01.2020]
     * @returns {JSX.Element}
     */
    Menu.prototype.render = function () {
        var _this = this;
        var _a = this.originalProps, anchorElement = _a.anchorElement, className = _a.className, heightRestricted = _a.heightRestricted, inline = _a.inline, positionConfiguration = _a.positionConfiguration, width = _a.width;
        var opened = this.state.opened;
        return util_1.ConditionUtils.orNull(opened, function () { return (React.createElement(dialog_component_1.Dialog, { ref: _this.dialogRef, closable: false, acceptable: false, default: false, scrollable: false, inline: inline, width: width, positionConfiguration: positionConfiguration, anchorElement: anchorElement, className: util_1.ClsUtils.joinClassName(definition_1.MenuClassesEnum.MENU, util_1.CalcUtils.calc(className), heightRestricted && definition_1.MenuClassesEnum.MENU_HEIGHT_RESTRICTED), onActivate: _this.onDialogActivate, onDeactivate: _this.onDialogDeactivate },
            !_this.isAnchored && (React.createElement(React.Fragment, null,
                _this.closeActionElement,
                _this.inlineOptionsElement,
                _this.isFilterUsed && _this.filterElement)),
            _this.listElement,
            _this.applyActionsElement)); });
    };
    /**
     * @stable [18.06.2019]
     */
    Menu.prototype.componentWillUnmount = function () {
        this.clearAll();
        this.filterQueryTask = null;
    };
    /**
     * @stable [31.01.2020]
     * @param {() => void} callback
     */
    Menu.prototype.show = function (callback) {
        var _this = this;
        this.setState({ filter: definitions_interface_1.UNDEF, opened: true }, function () {
            if (util_1.TypeUtils.isFn(callback)) {
                callback();
            }
            _this.onDialogAfterRender();
        });
    };
    /**
     * @stable [18.06.2019]
     */
    Menu.prototype.hide = function () {
        this.clearAll();
        this.setState({ opened: false }, this.onDialogAfterDestroy);
    };
    /**
     * @stable [29.11.2018]
     * @returns {boolean}
     */
    Menu.prototype.isOpen = function () {
        return this.state.opened;
    };
    /**
     * @stable [23.11.2019]
     */
    Menu.prototype.notifyFilterChange = function () {
        var props = this.props;
        if (util_1.TypeUtils.isFn(props.onFilterChange)) {
            props.onFilterChange(this.state.filter);
        }
    };
    /**
     * @stable [24.01.2020]
     * @param {string} filter
     */
    Menu.prototype.onFilterValueChange = function (filter) {
        var _this = this;
        this.setState({ filter: filter }, function () { return util_1.ConditionUtils.ifNotNilThanValue(_this.filterQueryTask, function (task) { return task.start(); }); });
    };
    /**
     * @stable [23.11.2019]
     * @param {IPresetsMenuItemEntity} option
     */
    Menu.prototype.onSelect = function (option) {
        var originalProps = this.originalProps;
        var multi = originalProps.multi, onSelect = originalProps.onSelect;
        if (util_1.TypeUtils.isFn(onSelect)) {
            onSelect(option);
        }
        if (multi && this.items.length > 1) {
            // Because a "Flux Cycle", to prevent empty list after updating
            return;
        }
        this.hide();
    };
    /**
     * @stable [06.01.2020]
     */
    Menu.prototype.onDialogDeactivate = function () {
        this.setState({ opened: false });
    };
    /**
     * @stable [25.01.2020]
     */
    Menu.prototype.onDialogActivate = function () {
        util_1.ConditionUtils.ifNotNilThanValue(this.field, function (field) { return field.setFocus(); });
    };
    /**
     * @stable [25.01.2020]
     */
    Menu.prototype.onDialogAfterRender = function () {
        util_1.ConditionUtils.ifNotNilThanValue(this.dialog, function (dialog) { return dialog.activate(); });
        if (this.isAnchored) {
            this.clearAll();
            this.scrollEventUnsubscriber = this.eventEmitter.subscribe({
                autoUnsubscribing: true,
                callback: this.hide,
                condition: this.scrollEventCallbackCondition,
                eventName: definition_1.SyntheticEmitterEventsEnum.SCROLL,
            });
            this.resizeUnsubscriber = this.domAccessor.captureEvent({
                autoUnsubscribing: true,
                callback: this.hide,
                eventName: definition_1.EventsEnum.RESIZE,
            });
        }
    };
    /**
     * @stable [25.01.2020]
     */
    Menu.prototype.onDialogAfterDestroy = function () {
        var props = this.props;
        if (util_1.TypeUtils.isFn(props.onClose)) {
            props.onClose();
        }
    };
    Object.defineProperty(Menu.prototype, "listElement", {
        /**
         * @stable [24.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var NO_DATA = this.settings.messages.NO_DATA;
            var maxCount = this.originalProps.maxCount;
            var items = util_1.subArray(this.items, maxCount);
            return (React.createElement(basic_list_component_1.BasicList, { forwardedRef: this.listElementRef, full: !this.isAnchored, plugins: perfect_scroll_plugin_1.PerfectScrollPlugin },
                items.map(function (option, index) { return _this.asItemElement(option, index, items.length); }),
                !items.length && (React.createElement("div", { className: definition_1.MenuClassesEnum.MENU_EMPTY_MESSAGE }, NO_DATA))));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [29.01.2020]
     * @param {IPresetsMenuItemEntity} option
     * @param {number} index
     * @param {number} length
     * @returns {JSX.Element}
     */
    Menu.prototype.asItemElement = function (option, index, length) {
        var props = this.props;
        return (React.createElement(list_item_component_1.ListItem, { key: "menu-item-key-" + option.value, disabled: option.disabled, icon: option.icon, iconLeftAligned: option.iconLeftAligned, rawData: option, odd: util_1.isHighlightOdd(props, index), last: index === length - 1, renderer: props.renderer, tpl: props.tpl, onClick: this.onSelect }, this.optionValueFn(option)));
    };
    Object.defineProperty(Menu.prototype, "inlineOptionsElement", {
        /**
         * @stable [08.07.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var _a = this.originalProps, inlineOptions = _a.inlineOptions, onInlineOptionClose = _a.onInlineOptionClose;
            return util_1.ConditionUtils.ifNotNilThanValue(inlineOptions, function () { return (React.createElement(basic_component_1.BasicComponent, { plugins: perfect_scroll_plugin_1.PerfectScrollPlugin, className: definition_1.MenuClassesEnum.MENU_INLINE_OPTIONS }, inlineOptions.map(function (option) { return (React.createElement(inline_option_component_1.InlineOption, { key: "inline-option-key-" + _this.fieldConverter.fromSelectValueToId(option), option: option, onClose: onInlineOptionClose })); }))); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "applyActionsElement", {
        /**
         * @stable [17.07.2020]
         */
        get: function () {
            var _this = this;
            var _a = this.originalProps, inlineOptions = _a.inlineOptions, multi = _a.multi;
            return util_1.ConditionUtils.orNull(multi, function () { return (React.createElement(button_component_1.Button, { raised: true, disabled: !util_1.ObjectUtils.isObjectNotEmpty(inlineOptions), icon: definition_1.IconsEnum.CHECK_CIRCLE, text: _this.settings.messages.APPLY, className: definition_1.MenuClassesEnum.MENU_APPLY_ACTION, onClick: _this.hide })); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "filterElement", {
        /**
         * @stable [17.01.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var props = this.props;
            var state = this.state;
            return (React.createElement(text_field_1.TextField, { ref: this.fieldRef, full: false, value: state.filter, placeholder: props.filterPlaceholder || this.settings.messages.SEARCH, errorMessageRendered: false, className: definition_1.MenuClassesEnum.MENU_FILTER, onChange: this.onFilterValueChange }));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "closeActionElement", {
        /**
         * @stable [07.07.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (this.uiFactory.makeIcon({
                type: definition_1.IconsEnum.TIMES,
                className: definition_1.MenuClassesEnum.MENU_ICON_CLOSE,
                onClick: this.hide,
            }));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.05.2020]
     * @param {HTMLElement} element
     * @returns {boolean}
     */
    Menu.prototype.scrollEventCallbackCondition = function (element) {
        return element !== this.listElementRef.current;
    };
    /**
     * @stable [24.01.2020]
     */
    Menu.prototype.clearAll = function () {
        this.unsubscribeAllEvents();
        util_1.ConditionUtils.ifNotNilThanValue(this.filterQueryTask, function (task) { return task.stop(); });
    };
    /**
     * @stable [23.11.2019]
     */
    Menu.prototype.unsubscribeAllEvents = function () {
        if (util_1.TypeUtils.isFn(this.scrollEventUnsubscriber)) {
            this.scrollEventUnsubscriber();
            this.scrollEventUnsubscriber = null;
        }
        if (util_1.TypeUtils.isFn(this.resizeUnsubscriber)) {
            this.resizeUnsubscriber();
            this.resizeUnsubscriber = null;
        }
    };
    Object.defineProperty(Menu.prototype, "isAnchored", {
        /**
         * @stable [24.01.2020]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.props.anchorElement);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "isFilterUsed", {
        /**
         * @stable [23.11.2019]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isFilterUsed(this.props);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "items", {
        /**
         * @stable [23.11.2019]
         * @returns {IPresetsMenuItemEntity[]}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            return !this.isFilterUsed || util_1.isRemoteFilterApplied(props)
                ? props.options
                : props.options.filter(function (option) { return props.filter(_this.state.filter, option); });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "field", {
        /**
         * @stable [07.06.2018]
         * @returns {TextField}
         */
        get: function () {
            return this.fieldRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Menu.prototype, "dialog", {
        /**
         * @stable [17.06.2019]
         * @returns {Dialog}
         */
        get: function () {
            return this.dialogRef.current;
        },
        enumerable: true,
        configurable: true
    });
    Menu.defaultProps = {
        delayTimeout: 1000,
        heightRestricted: true,
        filter: function (query, entity) { return util_1.queryFilter(query, entity.label || entity.value); },
    };
    return Menu;
}(generic_component_1.GenericComponent));
exports.Menu = Menu;
//# sourceMappingURL=menu.component.js.map