"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var filter_1 = require("./filter");
var cond_1 = require("./cond");
var definition_1 = require("../definition");
var select_1 = require("./select");
var wrapper_1 = require("./wrapper");
var entity_1 = require("./entity");
var nvl_1 = require("./nvl");
var type_1 = require("./type");
var map_as_wrapper_1 = require("./map-as-wrapper");
/**
 * @map-as
 * @map-as-original
 * @map-as-wrapper
 */
/**
 * @map-as-original
 *
 * @stable [26.07.2020]
 * @param wrapper
 */
var mapSectionNameWrapper = function (wrapper) {
    return map_as_wrapper_1.MapAsWrapperUtils.sectionName(select_1.Selectors.sectionName(wrapper));
};
/**
 * @map-as-original
 *
 * @stable [26.07.2020]
 * @param {IReduxHolderQueryFilterEntity} entity
 * @returns {IReduxHolderQueryFilterEntity}
 */
var mapHolderQueryFilterEntity = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.queryFilter(select_1.Selectors.queryFilter(entity));
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param {IReduxHolderListEntity} entity
 * @returns {IReduxHolderListEntity}
 */
var mapHolderListEntity = function (entity) { return map_as_wrapper_1.MapAsWrapperUtils.list(select_1.Selectors.list(entity)); };
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param {IReduxHolderFormEntity<TEntity>} entity
 * @returns {IReduxHolderFormEntity<TEntity>}
 */
var mapHolderFormEntity = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.form(select_1.Selectors.form(entity));
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapHolderChannelEntity = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.channel(select_1.Selectors.channel(entity));
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapHolderNotificationEntity = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.notification(select_1.Selectors.notification(entity));
};
/**
 * @map-as-original
 *
 * @stable [12.06.2020]
 * @param {IReduxHolderTransportEntity<TEntity>} entity
 * @returns {IReduxHolderTransportEntity<TEntity>}
 */
var mapHolderTransportEntity = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.transport(select_1.Selectors.transport(entity));
};
/**
 * @map-as
 *
 * @stable [09.06.2020]
 * @param {IProgressWrapper} entity
 * @returns {IDisabledWrapper}
 */
var mapProgressAsDisabled = function (entity) { return map_as_wrapper_1.MapAsWrapperUtils.disabled(wrapper_1.WrapperUtils.inProgress(entity)); };
/**
 * @map-as
 *
 * @stable [08.07.2020]
 * @param {IReduxHolderListEntity} listEntity
 * @returns {IDisabledWrapper}
 */
var mapHolderListEntityAsDisabled = function (listEntity) {
    return mapProgressAsDisabled(select_1.Selectors.list(listEntity));
};
/**
 * @map-as
 *
 * @stable [08.07.2020]
 * @param {INamedEntity} entity
 * @returns {IPresetsRawDataLabeledValueEntity}
 */
var mapNamedEntityAsRawDataLabeledValueEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return (filter_1.FilterUtils.defValuesFilter({
        value: entity.id,
        label: entity.name || String(entity.id),
        rawData: entity,
    })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapSecondaryFilterFormEntityAsHolderFormEntity = function (entity) {
    return mapHolderFormEntity(select_1.Selectors.secondaryFilter(entity));
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapHolderQueryFilterEntityAsQuery = function (entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.query(select_1.Selectors.queryFilterEntityQuery(entity));
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param {IReduxPagedEntity} entity
 * @returns {IReduxPagedEntity}
 */
var mapPagedEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.FilterUtils.defValuesFilter({
        page: entity.page,
        pageSize: entity.pageSize,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param extendedEntity
 */
var mapExtendedEntity = function (extendedEntity) {
    return filter_1.FilterUtils.defValuesFilter({
        changes: extendedEntity.changes,
        entity: extendedEntity.entity,
        entityId: extendedEntity.entityId,
        newEntity: extendedEntity.newEntity,
        originalEntity: extendedEntity.originalEntity,
    });
};
/**
 * @stable [19.05.2020]
 * @param {IPresetsSelectOptionEntity<TRawData>} entity
 * @returns {IPresetsSelectOptionEntity<TRawData>}
 */
var mapSelectOptionEntity = function (entity) {
    return filter_1.FilterUtils.defValuesFilter({
        disabled: entity.disabled,
        label: entity.label,
        rawData: entity.rawData,
        value: entity.value,
    });
};
/**
 * @stable [19.05.2020]
 * @param {TEntity} entity
 * @returns {IPresetsSelectOptionEntity<TEntity extends IOptionEntity>}
 */
var mapOptionEntityAsSelectOptionEntity = function (entity) {
    return mapSelectOptionEntity({
        value: entity.id,
        label: entity.name,
        disabled: entity.disabled,
        rawData: entity,
    });
};
/**
 * @stable [19.05.2020]
 * @param {TEntity[] | TEntity} data
 * @returns {Array<IPresetsSelectOptionEntity<TEntity extends IOptionEntity>>}
 */
var mapOptionEntitiesAsSelectOptionEntities = function (data) {
    return cond_1.ConditionUtils.ifNotNilThanValue(data, function () { return [].concat(data).map(function (entity) { return mapOptionEntityAsSelectOptionEntity(entity); }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param formEntity
 * @param entity
 */
var mapEntityAsExtendedEntity = function (formEntity, entity) {
    var newEntity = entity_1.isNewEntity(entity);
    var _a = formEntity || {}, changes = _a.changes, defaultChanges = _a.defaultChanges;
    var originalEntity;
    if (!R.isNil(nvl_1.NvlUtils.nvl(defaultChanges, entity))) {
        originalEntity = __assign({}, defaultChanges, entity);
    }
    return mapExtendedEntity({
        changes: changes,
        entity: __assign({}, originalEntity, changes),
        entityId: cond_1.ConditionUtils.orUndef(!newEntity, function () { return entity.id; }),
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {IExtendedFormEntity<TEntity>}
 */
var mapEntityAsExtendedFormEntity = function (formEntity, entity) {
    return (__assign({}, map_as_wrapper_1.MapAsWrapperUtils.form(formEntity), mapEntityAsExtendedEntity(formEntity, entity)));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapExtendedFormEntityAsFinalEntity = function (formEntity, entity) {
    return mapEntityAsExtendedFormEntity(formEntity, entity).entity;
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param holderListEntity
 * @param formEntity
 */
var mapListSelectedEntityAsExtendedFormEntity = function (holderListEntity, formEntity) {
    return mapEntityAsExtendedFormEntity(formEntity, select_1.Selectors.listSelectedEntity(holderListEntity));
};
/**
 * @stable [10.05.2020]
 * @param {IReduxHolderListEntity<TEntity>} listEntity
 * @param {IReduxFormEntity<TEntity>} formEntity
 * @returns {TEntity}
 */
var mapListSelectedExtendedFormEntityAsFinalEntity = function (listEntity, formEntity) {
    return mapListSelectedEntityAsExtendedFormEntity(listEntity, formEntity).entity;
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapQueryFilterEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.FilterUtils.defValuesFilter({
        active: entity.active,
        query: entity.query,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param entity
 */
var mapLifeCycleEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.FilterUtils.defValuesFilter({
        error: entity.error,
        progress: entity.progress,
        touched: entity.touched,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @map-as-original
 *
 * @stable [27.07.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {IReduxPaginatedEntity}
 */
var mapPaginatedEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.FilterUtils.defValuesFilter(__assign({}, mapPagedEntity(entity), { lockPage: entity.lockPage, totalAmount: entity.totalAmount, totalCount: entity.totalCount })); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @param {number} pageSize
 * @returns {IReduxPagedEntity}
 */
var mapPaginatedEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definition_1.DEFAULT_PAGE_SIZE; }
    return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return mapPagedEntity({
        page: entity.lockPage ? entity.page : definition_1.FIRST_PAGE,
        pageSize: pageSize,
    }); }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @mapper
 * @stable [09.05.2020]
 * @param {IReduxHolderListEntity} entity
 * @param {number} pageSize
 * @returns {IReduxPagedEntity}
 */
var mapListEntityAsPagedEntity = function (entity, pageSize) {
    if (pageSize === void 0) { pageSize = definition_1.DEFAULT_PAGE_SIZE; }
    return mapPaginatedEntityAsPagedEntity(select_1.Selectors.list(entity), pageSize);
};
/**
 * @map-as-original
 *
 * @stable [10.06.2020]
 * @param {IReduxPaginatedLifeCycleEntity} entity
 * @returns {IReduxPaginatedLifeCycleEntity}
 */
var mapPaginatedLifeCycleEntity = function (entity) { return (__assign({}, mapLifeCycleEntity(entity), mapPaginatedEntity(entity))); };
/**
 * @map-as-original
 *
 * @stable [09.06.2020]
 * @param {IReduxHolderLayoutEntity<TEntity>} wrapper
 * @returns {IReduxHolderLayoutEntity<TEntity>}
 */
var mapHolderLayoutEntity = function (wrapper) {
    return map_as_wrapper_1.MapAsWrapperUtils.layout(select_1.Selectors.layout(wrapper));
};
/**
 * @map-as-original
 *
 * @stable [09.06.2020]
 * @param {IReduxHolderStackEntity<TEntity>} wrapper
 * @returns {IReduxHolderStackEntity<TEntity>}
 */
var mapHolderStackEntity = function (wrapper) {
    return map_as_wrapper_1.MapAsWrapperUtils.stack(select_1.Selectors.stack(wrapper));
};
/**
 * @map-as-original
 *
 * @stable [09.06.2020]
 * @param {IReduxHolderUserEntity<TEntity>} wrapper
 * @returns {IReduxHolderUserEntity<TEntity>}
 */
var mapHolderUserEntity = function (wrapper) {
    return map_as_wrapper_1.MapAsWrapperUtils.user(select_1.Selectors.user(wrapper));
};
/**
 * @map-as-original
 *
 * @stable [09.06.2020]
 * @param {IReduxHolderDictionariesEntity<TEntity>} wrapper
 * @returns {IReduxHolderDictionariesEntity<TEntity>}
 */
var mapHolderDictionariesEntity = function (wrapper) {
    return map_as_wrapper_1.MapAsWrapperUtils.dictionaries(select_1.Selectors.dictionaries(wrapper));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxHolderPrimaryFilterFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapPrimaryFilterEntityAsFinalEntity = function (formEntity, entity) {
    return mapExtendedFormEntityAsFinalEntity(select_1.Selectors.primaryFilter(formEntity), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxHolderSecondaryFilterFormEntity<TEntity>} formEntity
 * @param {TEntity} entity
 * @returns {TEntity}
 */
var mapSecondaryFilterEntityAsFinalEntity = function (formEntity, entity) {
    return mapExtendedFormEntityAsFinalEntity(select_1.Selectors.secondaryFilter(formEntity), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxHolderPrimaryFilterFormEntity<TEntity>} wrapper
 * @param {TEntity} entity
 * @returns {IPrimaryFilterExtendedFormEntity<TEntity>}
 */
var mapPrimaryFilterEntityAsPrimaryFilterExtendedFormEntity = function (wrapper, entity) {
    return mapEntityAsPrimaryFilterExtendedFormEntity(select_1.Selectors.primaryFilter(wrapper), entity);
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param formEntity
 * @param entity
 */
var mapEntityAsPrimaryFilterExtendedFormEntity = function (formEntity, entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.primaryFilter(mapEntityAsExtendedFormEntity(formEntity, entity));
};
/**
 * @map-as
 *
 * @stable [27.07.2020]
 * @param formEntity
 * @param entity
 */
var mapEntityAsSecondaryFilterExtendedFormEntity = function (formEntity, entity) {
    return map_as_wrapper_1.MapAsWrapperUtils.secondaryFilter(mapEntityAsExtendedFormEntity(formEntity, entity));
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param {IReduxHolderSecondaryFilterFormEntity<TEntity>} wrapper
 * @param {TEntity} entity
 * @returns {ISecondaryFilterExtendedFormEntity<TEntity>}
 */
var mapSecondaryFilterEntityAsSecondaryFilterExtendedFormEntity = function (wrapper, entity) {
    return mapEntityAsSecondaryFilterExtendedFormEntity(select_1.Selectors.secondaryFilter(wrapper), entity);
};
/**
 * @mapper
 * @stable [10.05.2020]
 * @param wrapper
 * @param cfg
 */
var mapFullSearchFilter = function (wrapper, cfg) {
    if (cfg === void 0) { cfg = { paging: true }; }
    return (__assign({}, mapHolderQueryFilterEntityAsQuery(wrapper), mapPrimaryFilterEntityAsFinalEntity(wrapper), mapSecondaryFilterEntityAsFinalEntity(wrapper), cfg.paging ? mapListEntityAsPagedEntity(wrapper) : {}));
};
/**
 * @stable [19.05.2020]
 * @param {IReduxDictionaryEntity<TEntity>} dictionaryEntity
 * @param {(data: (TEntity[] | TEntity)) => AnyT} accessor
 * @returns {Array<IPresetsSelectOptionEntity<TEntity>>}
 */
var mapDictionaryEntityAsSelectOptionEntities = function (dictionaryEntity, accessor) {
    return GenericMappers.optionEntitiesAsSelectOptionEntities(cond_1.ConditionUtils.ifNotNilThanValue(select_1.Selectors.data(dictionaryEntity), function (data) { return type_1.TypeUtils.isFn(accessor) ? accessor(data) : data; }));
};
/**
 * @stable [19.05.2020]
 * @param {IReduxDictionaryEntity<TEntity>} entity
 * @param {(data: TEntity[]) => TResult} accessor
 * @returns {IReduxBaseSelectEntity}
 */
var mapDictionaryEntityAsSelectEntity = function (entity, accessor) {
    return (__assign({}, map_as_wrapper_1.MapAsWrapperUtils.waitingForOptions(wrapper_1.WrapperUtils.isLoading(entity)), map_as_wrapper_1.MapAsWrapperUtils.options(mapDictionaryEntityAsSelectOptionEntities(entity, accessor))));
};
/**
 * @map-as-original
 *
 * @stable [09.06.2020]
 * @param {IReduxStoreEntity<TDictionaries>} entity
 * @returns {IReduxStoreEntity<TDictionaries>}
 */
var mapStoreEntity = function (entity) {
    return (__assign({}, mapHolderChannelEntity(entity), mapHolderDictionariesEntity(entity), mapHolderLayoutEntity(entity), mapHolderNotificationEntity(entity), mapHolderStackEntity(entity), mapHolderTransportEntity(entity), mapHolderUserEntity(entity)));
};
/**
 * @stable [06.05.2020]
 */
var GenericMappers = /** @class */ (function () {
    function GenericMappers() {
    }
    GenericMappers.dictionaryEntityAsSelectEntity = mapDictionaryEntityAsSelectEntity; /* stable [19.05.2020] */
    GenericMappers.dictionaryEntityAsSelectOptionEntities = mapDictionaryEntityAsSelectOptionEntities; /* stable [19.05.2020] */
    GenericMappers.entityAsExtendedEntity = mapEntityAsExtendedEntity; /* stable [08.05.2020] */
    GenericMappers.entityAsExtendedFormEntity = mapEntityAsExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.extendedEntity = mapExtendedEntity; /* stable [08.05.2020] */
    GenericMappers.fullSearchFilter = mapFullSearchFilter; /* stable [10.05.2020] */
    GenericMappers.holderDictionariesEntity = mapHolderDictionariesEntity; /* stable [09.06.2020] */
    GenericMappers.holderFormEntity = mapHolderFormEntity; /* stable [12.06.2020] */
    GenericMappers.holderListEntity = mapHolderListEntity; /* stable [12.06.2020] */
    GenericMappers.holderListEntityAsDisabled = mapHolderListEntityAsDisabled; /* stable [08.07.2020] */
    GenericMappers.holderNotificationEntity = mapHolderNotificationEntity; /* stable [12.06.2020] */
    GenericMappers.holderQueryFilterEntity = mapHolderQueryFilterEntity; /* stable [26.07.2020] */
    GenericMappers.holderQueryFilterEntityAsQuery = mapHolderQueryFilterEntityAsQuery; /* stable [27.07.2020] */
    GenericMappers.holderTransportEntity = mapHolderTransportEntity; /* stable [12.06.2020] */
    GenericMappers.holderUserEntity = mapHolderUserEntity; /* stable [09.06.2020] */
    GenericMappers.listEntityAsPagedEntity = mapListEntityAsPagedEntity; /* stable [09.05.2020] */
    GenericMappers.listSelectedEntityAsExtendedFormEntity = mapListSelectedEntityAsExtendedFormEntity; /* stable [09.05.2020] */
    GenericMappers.listSelectedExtendedFormEntityAsFinalEntity = mapListSelectedExtendedFormEntityAsFinalEntity; /* stable [10.05.2020] */
    GenericMappers.namedEntityAsRawDataLabeledValueEntity = mapNamedEntityAsRawDataLabeledValueEntity; /* stable [08.07.2020] */
    GenericMappers.optionEntitiesAsSelectOptionEntities = mapOptionEntitiesAsSelectOptionEntities; /* stable [19.05.2020] */
    GenericMappers.pagedEntity = mapPagedEntity; /* stable [07.05.2020] */
    GenericMappers.paginatedEntity = mapPaginatedEntity; /* stable [07.05.2020] */
    GenericMappers.paginatedLifeCycleEntity = mapPaginatedLifeCycleEntity; /* stable [07.05.2020] */
    GenericMappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity = mapPrimaryFilterEntityAsPrimaryFilterExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.queryFilterEntity = mapQueryFilterEntity; /* stable [27.07.2020] */
    GenericMappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity = mapSecondaryFilterEntityAsSecondaryFilterExtendedFormEntity; /* stable [10.05.2020] */
    GenericMappers.secondaryFilterFormEntityAsHolderFormEntity = mapSecondaryFilterFormEntityAsHolderFormEntity; /* stable [27.07.2020] */
    GenericMappers.sectionNameWrapper = mapSectionNameWrapper; /* stable [08.05.2020] */
    GenericMappers.storeEntity = mapStoreEntity; /* stable [09.06.2020] */
    return GenericMappers;
}());
exports.GenericMappers = GenericMappers;
//# sourceMappingURL=mapper-generic.js.map