import { IApiEntity, IExtendedEntity, IFormTabPanelContainerProps, IHeaderProps, IOperationEntity, IPresetsSelectableHoveredEntity, IReduxHolderTransportEntity, IReduxSortDirectionsEntity, ISortDirectionEntity, ISortDirectionsEntity, IUniversalApplicationEntity } from '../definition';
import { IActiveValueWrapper, IEntity, IEntityIdTWrapper } from '../definitions.interface';
/**
 * @stable [17.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @returns {string}
 */
export declare const selectTransportWrapperToken: (entity: IReduxHolderTransportEntity<import("core/definition/transport-definition.interface").IReduxTransportEntity>) => string;
/**
 * @stable [25.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @returns {string[]}
 */
export declare const selectTransportWrapperQueue: (entity: IReduxHolderTransportEntity<import("core/definition/transport-definition.interface").IReduxTransportEntity>) => string[];
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
export declare const mapEntityId: (id: string | number) => IEntityIdTWrapper;
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
export declare const mapSortDirectionsWrapperEntity: (directions: IReduxSortDirectionsEntity) => ISortDirectionsEntity;
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
export declare const mapIdentifiedEntity: (entity: IEntityIdTWrapper) => IEntityIdTWrapper;
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
export declare const mapActiveValue: <TActiveValue>(activeValue: TActiveValue) => IActiveValueWrapper<TActiveValue>;
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
export declare const mapSortDirectionEntity: (entity: ISortDirectionEntity) => ISortDirectionEntity;
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
export declare const mapActiveValueWrapper: <TValue>(wrapper: IActiveValueWrapper<TValue>) => IActiveValueWrapper<TValue>;
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
export declare const mapApiEntity: <TEntity = IEntity>(extendedEntity: IExtendedEntity<TEntity>) => IApiEntity<TEntity>;
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasQueueOperations: (queue: string[], ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [25.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
export declare const hasTransportWrapperQueueOperations: (entity: IReduxHolderTransportEntity<import("core/definition/transport-definition.interface").IReduxTransportEntity>, ...operations: (string | IOperationEntity)[]) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationInProgress: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const doesApplicationErrorExist: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
export declare const isApplicationMessageVisible: (entity: IUniversalApplicationEntity) => boolean;
/**
 * @container-props-mapper
 * @stable [13.04.2020]
 *
 * @param {IFormTabPanelContainerProps} props
 * @returns {IFormTabPanelContainerProps}
 */
export declare const mapFormTabPanelContainerProps: (props: IFormTabPanelContainerProps<IEntity>) => IFormTabPanelContainerProps<IEntity>;
/**
 * @stable [05.05.2020]
 */
export declare class Mappers {
    static readonly defaultLayoutContainerProps: (entity: import("core/definition/default-layout-definition.interface").IDefaultLayoutContainerProps) => import("core/definition/default-layout-definition.interface").IDefaultLayoutContainerProps;
    static readonly dictionaryEntityAsSelectEntity: <TEntity, TResult = TEntity[]>(entity: import("core/definition/dictionary-definition.interface").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity[]) => TResult) => import("core/definition/select-definition.interface").IReduxBaseSelectEntity;
    static readonly dictionaryEntityAsSelectOptionEntities: <TEntity>(dictionaryEntity: import("core/definition/dictionary-definition.interface").IReduxDictionaryEntity<TEntity>, accessor?: (data: TEntity | TEntity[]) => any) => import("core/definition/select-definition.interface").IPresetsSelectOptionEntity<TEntity, string | number>[];
    static readonly entityAsExtendedEntity: <TEntity extends IEntity = IEntity>(formEntity: import("core/definition/form-definition.interface").IReduxFormEntity<TEntity>, entity?: TEntity) => IExtendedEntity<TEntity>;
    static readonly entityAsExtendedFormEntity: <TEntity = IEntity>(formEntity: import("core/definition/form-definition.interface").IReduxFormEntity<TEntity>, entity?: TEntity) => import("core/definition/form-definition.interface").IExtendedFormEntity<TEntity>;
    static readonly filterFormDialogContainerProps: (props: import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps) => import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps;
    static readonly filterFormDialogSecondaryFilterContainerProps: (props: import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps & import("core/definition/form-definition.interface").ISecondaryFilterExtendedFormEntity<IEntity>) => import("core/definition/filter-form-dialog-definition.interface").IFilterFormDialogContainerProps;
    static readonly form: <TForm>(form: TForm) => import("core/definitions.interface").IFormWrapper<TForm>;
    static readonly formContainerProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>) => import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>;
    static readonly formContainerPropsAsFormProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>) => import("core/definition/form-definition.interface").IFormProps<IEntity>;
    static readonly formPrimaryFilterContainerProps: (props: import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}> & import("core/definition/form-definition.interface").IPrimaryFilterExtendedFormEntity<IEntity>) => import("core/definition/form-definition.interface").IFormContainerProps<IEntity, {}>;
    static readonly fullSearchFilter: <TFilter, TEntity = IEntity>(wrapper: import("core/definition/query-definition.interface").IReduxHolderQueryFilterEntity & import("core/definition/list-definition.interface").IReduxHolderListEntity<TEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<TEntity, any>>, cfg?: {
        paging: boolean;
    }) => TFilter;
    static readonly headerProps: (props: IHeaderProps) => IHeaderProps;
    static readonly holderFormEntity: <TEntity = IEntity>(entity: import("core/definition/form-definition.interface").IReduxHolderFormEntity<TEntity>) => import("core/definition/form-definition.interface").IReduxHolderFormEntity<TEntity>;
    static readonly holderListEntity: (entity: import("core/definition/list-definition.interface").IReduxHolderListEntity<IEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<IEntity, any>>) => import("core/definition/list-definition.interface").IReduxHolderListEntity<IEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<IEntity, any>>;
    static readonly holderListEntityAsDisabled: (listEntity: import("core/definition/list-definition.interface").IReduxHolderListEntity<IEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<IEntity, any>>) => import("core/definitions.interface").IDisabledWrapper<boolean>;
    static readonly holderQueryFilterEntity: (entity: import("core/definition/query-definition.interface").IReduxHolderQueryFilterEntity) => import("core/definition/query-definition.interface").IReduxHolderQueryFilterEntity;
    static readonly holderQueryFilterEntityAsQuery: (entity: import("core/definition/query-definition.interface").IReduxHolderQueryFilterEntity) => import("core/definitions.interface").IQueryWrapper<string>;
    static readonly holderTransportEntity: <TEntity = import("core/definition/transport-definition.interface").IReduxTransportEntity>(entity: IReduxHolderTransportEntity<TEntity>) => IReduxHolderTransportEntity<TEntity>;
    static readonly listContainerProps: (props: import("core/definition/list-definition.interface").IListContainerProps) => import("core/definition/list-definition.interface").IListContainerProps;
    static readonly listEntityAsPagedEntity: (entity: import("core/definition/list-definition.interface").IReduxHolderListEntity<IEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<IEntity, any>>, pageSize?: number) => import("core/definition/page-definition.interface").IReduxPagedEntity;
    static readonly listSelectedEntityAsExtendedFormEntity: <TEntity = IEntity>(holderListEntity: import("core/definition/list-definition.interface").IReduxHolderListEntity<TEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<TEntity, any>>, formEntity: import("core/definition/form-definition.interface").IReduxFormEntity<TEntity>) => import("core/definition/form-definition.interface").IExtendedFormEntity<TEntity>;
    static readonly namedEntityAsRawDataLabeledValueEntity: (entity: import("core/definition/entity-definition.interface").INamedEntity) => import("core/definition/entity-definition.interface").IPresetsRawDataLabeledValueEntity<IEntity, string | number>;
    static readonly optionEntitiesAsSelectOptionEntities: <TEntity extends import("core/definition/entity-definition.interface").IOptionEntity>(data: TEntity | TEntity[]) => import("core/definition/select-definition.interface").IPresetsSelectOptionEntity<TEntity, string | number>[];
    static readonly pagedEntity: (entity: import("core/definition/page-definition.interface").IReduxPagedEntity) => import("core/definition/page-definition.interface").IReduxPagedEntity;
    static readonly pageToolbarContainerProps: (props: import("core/definition/toolbar-definition.interface").IPageToolbarContainerProps) => import("core/definition/toolbar-definition.interface").IPageToolbarContainerProps;
    static readonly pageToolbarContainerPropsAsPageToolbarProps: (props: import("core/definition/toolbar-definition.interface").IPageToolbarContainerProps) => import("core/definition/toolbar-definition.interface").IPageToolbarProps;
    static readonly paginatedEntity: (entity: import("core/definition/page-definition.interface").IReduxPaginatedEntity) => import("core/definition/page-definition.interface").IReduxPaginatedEntity;
    static readonly placeFieldProps: (container: import("core/definition/container-definition.interface").IFieldsContainer) => import("core/definition/select-definition.interface").IGenericBaseSelectEntity;
    static readonly primaryFilterEntityAsPrimaryFilterExtendedFormEntity: <TEntity = IEntity>(wrapper: import("core/definition/form-definition.interface").IReduxHolderPrimaryFilterFormEntity<TEntity>, entity?: TEntity) => import("core/definition/form-definition.interface").IPrimaryFilterExtendedFormEntity<TEntity>;
    static readonly searchToolbarContainerProps: (props: import("core/definition/toolbar-definition.interface").ISearchToolbarContainerProps) => import("core/definition/toolbar-definition.interface").ISearchToolbarContainerProps;
    static readonly secondaryFilterEntityAsSecondaryFilterExtendedFormEntity: <TEntity = IEntity>(wrapper: import("core/definition/form-definition.interface").IReduxHolderSecondaryFilterFormEntity<TEntity>, entity?: TEntity) => import("core/definition/form-definition.interface").ISecondaryFilterExtendedFormEntity<TEntity>;
    static readonly sectionNameWrapper: (wrapper: import("core/definitions.interface").ISectionNameWrapper) => import("core/definitions.interface").ISectionNameWrapper;
    static readonly selectableHoveredEntity: (entity: IPresetsSelectableHoveredEntity) => IPresetsSelectableHoveredEntity;
    static readonly selectedExtendedFormEntityAsFinalEntity: <TEntity = IEntity>(listEntity: import("core/definition/list-definition.interface").IReduxHolderListEntity<TEntity, any, import("core/definition/list-definition.interface").IReduxListEntity<TEntity, any>>, formEntity: import("core/definition/form-definition.interface").IReduxFormEntity<TEntity>) => TEntity;
    static readonly storeEntity: <TDictionaries = {}>(entity: import("core/definition/redux-definition.interface").IReduxStoreEntity<TDictionaries>) => import("core/definition/redux-definition.interface").IReduxStoreEntity<TDictionaries>;
    static readonly tabPanelHolderEntity: <TEntity = import("core/definition/tab-panel-definition.interface").IReduxTabPanelEntity>(entity: import("core/definition/tab-panel-definition.interface").IReduxTabPanelHolderEntity<TEntity>) => import("core/definition/tab-panel-definition.interface").IReduxTabPanelHolderEntity<TEntity>;
    static readonly toolbarToolsContainerProps: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>;
    static readonly toolbarToolsContainerPropsAsToolbarToolsProps: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps;
    static readonly toolbarToolsSecondaryFilterContainerProps: (props: import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps> & import("core/definition/form-definition.interface").ISecondaryFilterFormEntity<IEntity>) => import("core/definition/toolbar-tools-definition.interface").IToolbarToolsContainerProps<import("core/definition/toolbar-tools-definition.interface").IToolbarToolsProps>;
    static readonly unsavedFormChangesDialogContainerProps: (props: import("core/definition/unsaved-form-changes-dialog-definition.interface").IUnsavedFormChangesDialogContainerProps, proxyContainer: import("core/definition/generic-container-definition.interface").IGenericContainer<import("core/definition/generic-container-definition.interface").IGenericContainerProps<{}, any>, {}>) => import("core/definition/unsaved-form-changes-dialog-definition.interface").IUnsavedFormChangesDialogContainerProps;
    static readonly unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps: (props: import("core/definition/unsaved-form-changes-dialog-definition.interface").IUnsavedFormChangesDialogContainerProps) => import("core/definition/unsaved-form-changes-dialog-definition.interface").IUnsavedFormChangesDialogProps;
}
