"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var filter_1 = require("./filter");
var definitions_interface_1 = require("../definitions.interface");
var cond_1 = require("./cond");
var type_1 = require("./type");
var wrapper_1 = require("./wrapper");
var select_1 = require("./select");
var mapper_generic_1 = require("./mapper-generic");
var mapper_component_1 = require("./mapper-component");
var map_as_wrapper_1 = require("./map-as-wrapper");
var map_as_original_1 = require("./map-as-original");
/**
 * @stable [17.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @returns {string}
 */
exports.selectTransportWrapperToken = function (entity) {
    return select_1.selectToken(select_1.Selectors.transport(entity));
};
/**
 * @stable [25.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @returns {string[]}
 */
exports.selectTransportWrapperQueue = function (entity) {
    return select_1.Selectors.queue(select_1.Selectors.transport(entity));
};
/**
 * @stable [20.10.2019]
 * @param {EntityIdT} id
 * @returns {IEntityIdTWrapper}
 */
exports.mapEntityId = function (id) {
    return filter_1.defValuesFilter({ id: id });
};
/**
 * @stable [13.11.2019]
 * @param {IReduxSortDirectionsEntity} directions
 * @returns {ISortDirectionsEntity}
 */
exports.mapSortDirectionsWrapperEntity = function (directions) {
    return filter_1.defValuesFilter({ directions: directions });
};
/**
 * @stable [20.10.2019]
 * @param {IEntityIdTWrapper} entity
 * @returns {IEntityIdTWrapper}
 */
exports.mapIdentifiedEntity = function (entity) {
    return exports.mapEntityId(select_1.selectEntityId(entity));
};
/**
 * @stable [12.04.2020]
 * @param {TActiveValue} activeValue
 * @returns {IActiveValueWrapper<TActiveValue>}
 */
exports.mapActiveValue = function (activeValue) {
    return filter_1.defValuesFilter({ activeValue: activeValue });
};
/**
 * @stable [04.05.2020]
 * @mapper
 *
 * @param {IPresetsSelectableHoveredEntity} entity
 * @returns {IPresetsSelectableHoveredEntity}
 */
var mapSelectableHoveredEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    hovered: entity.hovered,
    selectable: entity.selectable,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [13.11.2019]
 * @param {ISortDirectionEntity} entity
 * @returns {ISortDirectionEntity}
 */
exports.mapSortDirectionEntity = function (entity) { return cond_1.ConditionUtils.ifNotNilThanValue(entity, function () { return filter_1.defValuesFilter({
    index: entity.index,
    direction: entity.direction,
}); }, definitions_interface_1.UNDEF_SYMBOL); };
/**
 * @stable [12.04.2020]
 * @param {IActiveValueWrapper<TValue>} wrapper
 * @returns {IActiveValueWrapper<TValue>}
 */
exports.mapActiveValueWrapper = function (wrapper) {
    return exports.mapActiveValue(select_1.selectActiveValue(wrapper));
};
/**
 * @stable [23.12.2019]
 * @param {IExtendedEntity<TEntity>} extendedEntity
 * @returns {IApiEntity<TEntity>}
 */
exports.mapApiEntity = function (extendedEntity) {
    var changes = extendedEntity.changes, entity = extendedEntity.entity, originalEntity = extendedEntity.originalEntity;
    var entityId = select_1.selectEntityId(entity);
    var newEntity = R.isNil(entityId);
    return filter_1.defValuesFilter({
        changes: changes,
        diff: newEntity ? entity : changes,
        entity: entity,
        entityId: entityId,
        newEntity: newEntity,
        originalEntity: originalEntity,
    });
};
/**
 * @stable [25.11.2019]
 * @param {string[]} queue
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasQueueOperations = function (queue) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return !R.isEmpty(R.intersection(queue, operations.map(function (operation) { return (type_1.TypeUtils.isString(operation)
        ? operation
        : operation.id); })));
};
/**
 * @stable [25.11.2019]
 * @param {IReduxHolderTransportEntity} entity
 * @param {string | IOperationEntity} operations
 * @returns {boolean}
 */
exports.hasTransportWrapperQueueOperations = function (entity) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    return exports.hasQueueOperations.apply(void 0, [exports.selectTransportWrapperQueue(entity)].concat(operations));
};
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationInProgress = function (entity) { return wrapper_1.inProgress(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.doesApplicationErrorExist = function (entity) { return wrapper_1.doesErrorExist(entity); };
/**
 * @stable [28.11.2019]
 * @param {IUniversalApplicationEntity} entity
 * @returns {boolean}
 */
exports.isApplicationMessageVisible = function (entity) {
    return exports.isApplicationInProgress(entity) || exports.doesApplicationErrorExist(entity) || !wrapper_1.isReady(entity);
};
/**
 * @container-props-mapper
 * @stable [13.04.2020]
 *
 * @param {IFormTabPanelContainerProps} props
 * @returns {IFormTabPanelContainerProps}
 */
exports.mapFormTabPanelContainerProps = function (props) {
    return (__assign({}, mapper_generic_1.GenericMappers.sectionNameWrapper(props), mapper_generic_1.GenericMappers.holderFormEntity(props)));
};
var mapHeaderProps = function (props) { return mapper_generic_1.GenericMappers.storeEntity(props); };
/**
 * @stable [05.05.2020]
 */
// tslint:disable:max-line-length
var Mappers = /** @class */ (function () {
    function Mappers() {
    }
    Mappers.defaultLayoutContainerProps = mapper_component_1.ComponentMappers.defaultLayoutContainerProps; /* @stable [12.06.2020] */
    Mappers.dictionaryEntityAsSelectEntity = mapper_generic_1.GenericMappers.dictionaryEntityAsSelectEntity; /* @stable [19.05.2020] */
    Mappers.dictionaryEntityAsSelectOptionEntities = mapper_generic_1.GenericMappers.dictionaryEntityAsSelectOptionEntities; /* @stable [19.05.2020] */
    Mappers.entityAsExtendedEntity = mapper_generic_1.GenericMappers.entityAsExtendedEntity; /* @stable [10.05.2020] */
    Mappers.entityAsExtendedFormEntity = mapper_generic_1.GenericMappers.entityAsExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.filterFormDialogContainerProps = mapper_component_1.ComponentMappers.filterFormDialogContainerProps; /* @stable [10.05.2020] */
    Mappers.filterFormDialogSecondaryFilterContainerProps = mapper_component_1.ComponentMappers.filterFormDialogSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    Mappers.form = map_as_wrapper_1.MapAsWrapperUtils.form; /* @stable [27.07.2020] */
    Mappers.formContainerProps = mapper_component_1.ComponentMappers.formContainerProps; /* @stable [08.05.2020] */
    Mappers.formContainerPropsAsFormProps = mapper_component_1.ComponentMappers.formContainerPropsAsFormProps; /* @stable [09.05.2020] */
    Mappers.formPrimaryFilterContainerProps = mapper_component_1.ComponentMappers.formPrimaryFilterContainerProps; /* @stable [10.05.2020] */
    Mappers.fullSearchFilter = mapper_generic_1.GenericMappers.fullSearchFilter; /* @stable [10.05.2020] */
    Mappers.headerProps = mapHeaderProps;
    Mappers.holderFormEntity = mapper_generic_1.GenericMappers.holderFormEntity; /* @stable [12.06.2020] */
    Mappers.holderListEntity = mapper_generic_1.GenericMappers.holderListEntity; /* @stable [12.06.2020] */
    Mappers.holderListEntityAsDisabled = mapper_generic_1.GenericMappers.holderListEntityAsDisabled; /* @stable [08.07.2020] */
    Mappers.holderQueryFilterEntity = mapper_generic_1.GenericMappers.holderQueryFilterEntity; /* @stable [26.07.2020] */
    Mappers.holderQueryFilterEntityAsQuery = mapper_generic_1.GenericMappers.holderQueryFilterEntityAsQuery; /* @stable [27.07.2020] */
    Mappers.holderTransportEntity = mapper_generic_1.GenericMappers.holderTransportEntity; /* @stable [12.06.2020] */
    Mappers.listContainerProps = mapper_component_1.ComponentMappers.listContainerProps; /* @stable [10.05.2020] */
    Mappers.listEntityAsPagedEntity = mapper_generic_1.GenericMappers.listEntityAsPagedEntity; /* @stable [08.05.2020] */
    Mappers.listSelectedEntityAsExtendedFormEntity = mapper_generic_1.GenericMappers.listSelectedEntityAsExtendedFormEntity; /* @stable [08.05.2020] */
    Mappers.namedEntityAsRawDataLabeledValueEntity = mapper_generic_1.GenericMappers.namedEntityAsRawDataLabeledValueEntity; /* @stable [08.07.2020] */
    Mappers.optionEntitiesAsSelectOptionEntities = mapper_generic_1.GenericMappers.optionEntitiesAsSelectOptionEntities; /* @stable [19.05.2020] */
    Mappers.pagedEntity = mapper_generic_1.GenericMappers.pagedEntity;
    Mappers.pageToolbarContainerProps = mapper_component_1.ComponentMappers.pageToolbarContainerProps;
    Mappers.pageToolbarContainerPropsAsPageToolbarProps = mapper_component_1.ComponentMappers.pageToolbarContainerPropsAsPageToolbarProps; /* @stable [15.06.2020] */
    Mappers.paginatedEntity = mapper_generic_1.GenericMappers.paginatedEntity;
    Mappers.placeFieldProps = mapper_component_1.ComponentMappers.placeFieldProps; /* @stable [19.05.2020] */
    Mappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity = mapper_generic_1.GenericMappers.primaryFilterEntityAsPrimaryFilterExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.searchToolbarContainerProps = mapper_component_1.ComponentMappers.searchToolbarContainerProps;
    Mappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity = mapper_generic_1.GenericMappers.secondaryFilterEntityAsSecondaryFilterExtendedFormEntity; /* @stable [10.05.2020] */
    Mappers.sectionNameWrapper = mapper_generic_1.GenericMappers.sectionNameWrapper;
    Mappers.selectableHoveredEntity = mapSelectableHoveredEntity;
    Mappers.selectedExtendedFormEntityAsFinalEntity = mapper_generic_1.GenericMappers.listSelectedExtendedFormEntityAsFinalEntity; /* @stable [10.05.2020] */
    Mappers.storeEntity = mapper_generic_1.GenericMappers.storeEntity; /* @stable [09.06.2020] */
    Mappers.tabPanelHolderEntity = map_as_original_1.MapAsOriginalUtils.tabPanelHolderEntity; /* @stable [29.07.2020] */
    Mappers.toolbarToolsContainerProps = mapper_component_1.ComponentMappers.toolbarToolsContainerProps; /* @stable [09.05.2020] */
    Mappers.toolbarToolsContainerPropsAsToolbarToolsProps = mapper_component_1.ComponentMappers.toolbarToolsContainerPropsAsToolbarToolsProps; /* @stable [10.06.2020] */
    Mappers.toolbarToolsSecondaryFilterContainerProps = mapper_component_1.ComponentMappers.toolbarToolsSecondaryFilterContainerProps; /* @stable [10.05.2020] */
    Mappers.unsavedFormChangesDialogContainerProps = mapper_component_1.ComponentMappers.unsavedFormChangesDialogContainerProps; /* @stable [15.06.2020] */
    Mappers.unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps = mapper_component_1.ComponentMappers.unsavedFormChangesDialogContainerPropsAsUnsavedFormChangesDialogProps; /* @stable [15.06.2020] */
    return Mappers;
}());
exports.Mappers = Mappers;
// tslint:enable:max-line-length
//# sourceMappingURL=mapper.js.map